//---     
#include "..\ReportInExcel.mq5"
//---   
#include "Auxiliary.mqh"
#include "InitializeArrays.mqh"
#include "FileFunctions.mqh"
#include "Enums.mqh"
#include "Errors.mqh"
#include "ToString.mqh"
#include "TradeSignals.mqh"
//---    
struct HistoryDealProperties
  {
   string            symbol;     // 
   string            comment;    // 
   ENUM_DEAL_TYPE    type;       //  
   ENUM_DEAL_ENTRY   entry;      // 
   double            price;      // 
   double            profit;     // /
   double            volume;     // 
   double            swap;       // 
   double            commission; // 
   datetime          time;       // 
  };
//---   
HistoryDealProperties  deal;
//+------------------------------------------------------------------+
//|                                    |
//+------------------------------------------------------------------+
void GetHistoryDealProperties(ulong ticket_number,ENUM_DEAL_PROPERTIES history_deal_property)
  {
   switch(history_deal_property)
     {
      case D_SYMBOL     : deal.symbol=HistoryDealGetString(ticket_number,DEAL_SYMBOL);                 break;
      case D_COMMENT    : deal.comment=HistoryDealGetString(ticket_number,DEAL_COMMENT);               break;
      case D_TYPE       : deal.type=(ENUM_DEAL_TYPE)HistoryDealGetInteger(ticket_number,DEAL_TYPE);    break;
      case D_ENTRY      : deal.entry=(ENUM_DEAL_ENTRY)HistoryDealGetInteger(ticket_number,DEAL_ENTRY); break;
      case D_PRICE      : deal.price=HistoryDealGetDouble(ticket_number,DEAL_PRICE);                   break;
      case D_PROFIT     : deal.profit=HistoryDealGetDouble(ticket_number,DEAL_PROFIT);                 break;
      case D_VOLUME     : deal.volume=HistoryDealGetDouble(ticket_number,DEAL_VOLUME);                 break;
      case D_SWAP       : deal.swap=HistoryDealGetDouble(ticket_number,DEAL_SWAP);                     break;
      case D_COMMISSION : deal.commission=HistoryDealGetDouble(ticket_number,DEAL_COMMISSION);         break;
      case D_TIME       : deal.time=(datetime)HistoryDealGetInteger(ticket_number,DEAL_TIME);          break;
      case D_ALL        :
         deal.symbol=HistoryDealGetString(ticket_number,DEAL_SYMBOL);
         deal.comment=HistoryDealGetString(ticket_number,DEAL_COMMENT);
         deal.type=(ENUM_DEAL_TYPE)HistoryDealGetInteger(ticket_number,DEAL_TYPE);
         deal.entry=(ENUM_DEAL_ENTRY)HistoryDealGetInteger(ticket_number,DEAL_ENTRY);
         deal.price=HistoryDealGetDouble(ticket_number,DEAL_PRICE);
         deal.profit=HistoryDealGetDouble(ticket_number,DEAL_PROFIT);
         deal.volume=HistoryDealGetDouble(ticket_number,DEAL_VOLUME);
         deal.swap=HistoryDealGetDouble(ticket_number,DEAL_SWAP);
         deal.commission=HistoryDealGetDouble(ticket_number,DEAL_COMMISSION);
         deal.time=(datetime)HistoryDealGetInteger(ticket_number,DEAL_TIME);                           break;
         //---
      default: Print("      !");                          return;
     }
  }
//+------------------------------------------------------------------+
//|        CSV              |
//+------------------------------------------------------------------+
void CreateSymbolBalanceReport()
  {
   int    file_handle =INVALID_HANDLE; //  
   string path        ="";             //   

//---    / , 
   if((path=CreateInputParametersFolder())=="")
      return;
//---         
   file_handle=FileOpen(path+"\\LastTest.csv",FILE_CSV|FILE_WRITE|FILE_ANSI|FILE_COMMON);
//---    ( /)
   if(file_handle>0)
     {
      int    digits          =0;   //      
      int    deals_total     =0;   //    
      ulong  ticket          =0;   //  
      double max_drawdown    =0.0; //  
      double balance         =0.0; // 
      //---
      string delimeter       =","; // 
      string string_to_write ="";  //     

      //---   
      string headers="TIME,SYMBOL,DEAL TYPE,ENTRY TYPE,VOLUME,PRICE,SWAP($),PROFIT($),DRAWDOWN(%),BALANCE";
      //---     ,    
      if(SYMBOLS_COUNT>1)
        {
         for(int s=0; s<SYMBOLS_COUNT; s++)
            StringAdd(headers,","+InputSymbols[s]);
        }
      //---   
      FileWrite(file_handle,headers);
      //---   
      HistorySelect(0,TimeCurrent());
      //---   
      deals_total=HistoryDealsTotal();
      //---      - 
      ArrayResize(symbol_balance,SYMBOLS_COUNT);
      //---       
      for(int s=0; s<SYMBOLS_COUNT; s++)
         ArrayResize(symbol_balance[s].balance,deals_total);
      //---      
      for(int i=0; i<deals_total; i++)
        {
         //---   
         ticket=HistoryDealGetTicket(i);
         //---    
         GetHistoryDealProperties(ticket,D_ALL);
         //---  -   
         digits=(int)SymbolInfoInteger(deal.symbol,SYMBOL_DIGITS);
         //---   
         balance+=deal.profit+deal.swap+deal.commission;
         //---      
         StringConcatenate(string_to_write,
                           deal.time,delimeter,
                           DealSymbolToString(deal.symbol),delimeter,
                           DealTypeToString(deal.type),delimeter,
                           DealEntryToString(deal.entry),delimeter,
                           DealVolumeToString(deal.volume),delimeter,
                           DealPriceToString(deal.price,digits),delimeter,
                           DealSwapToString(deal.swap),delimeter,
                           DealProfitToString(deal.symbol,deal.profit),delimeter,
                           MaxDrawdownToString(i,balance,max_drawdown),delimeter,
                           DoubleToString(balance,2));

         //---     ,     
         if(SYMBOLS_COUNT>1)
           {
            //---    
            for(int s=0; s<SYMBOLS_COUNT; s++)
              {
               //---       
               if(deal.symbol==InputSymbols[s] && deal.profit!=0)
                 {
                  //---       
                  //       
                  symbol_balance[s].balance[i]=symbol_balance[s].balance[i-1]+
                                               deal.profit+
                                               deal.swap+
                                               deal.commission;
                  //---   
                  StringAdd(string_to_write,","+DoubleToString(symbol_balance[s].balance[i],2));
                 }
               //---    
               else
                 {
                  //---    " " ( )
                  if(deal.type==DEAL_TYPE_BALANCE)
                    {
                     //---     
                     symbol_balance[s].balance[i]=balance;
                     StringAdd(string_to_write,","+DoubleToString(symbol_balance[s].balance[i],2));
                    }
                  //---       
                  else
                    {
                     symbol_balance[s].balance[i]=symbol_balance[s].balance[i-1];
                     StringAdd(string_to_write,","+DoubleToString(symbol_balance[s].balance[i],2));
                    }
                 }
              }
           }
         //---   
         FileWrite(file_handle,string_to_write);
         //---      
         string_to_write="";
        }
      //---  
      FileClose(file_handle);
     }
//---    /,  
   else
      Print("  : "+IntegerToString(GetLastError())+"");
  }
//+------------------------------------------------------------------+
